@font-face{font-family:ChineseFont;src:url(/static/media/Ubuntu%20Mono%20derivative%20Powerline.c0be5cec3f96a09ecb05.ttf) format("truetype")}@font-face{font-family:ChineseFontBold;src:url(/static/media/Ubuntu%20Mono%20derivative%20Powerline%20Bold.4ba5f7c4c75b9cd3c5c6.ttf) format("truetype")}body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;margin:0}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}
/*# sourceMappingURL=main.7daf22ea.css.map*/